@@ -19,7 +19,7 @@ TodoSortFilterProxyModel::TodoSortFilterProxyModel(QObject *parent)
     setFilterCaseSensitivity(Qt::CaseInsensitive);
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup rColorsConfig(config, "Resources Colors");
+    KConfigGroup rColorsConfig(config, QStringLiteral("Resources Colors"));
     m_colorWatcher = KConfigWatcher::create(config);
     QObject::connect(m_colorWatcher.data(), &KConfigWatcher::configChanged, this, &TodoSortFilterProxyModel::loadColors);
 
@@ -50,6 +50,7 @@ QHash<int, QByteArray> TodoSortFilterProxyModel::roleNames() const
     roleNames[Roles::CollectionIdRole] = "collectionId";
     roleNames[Roles::DurationStringRole] = "durationString";
     roleNames[Roles::RecursRole] = "recurs";
+    roleNames[Roles::IsReadOnly] = "isReadOnly";
     roleNames[Roles::IsOverdueRole] = "isOverdue";
     roleNames[Roles::IncidenceIdRole] = "incidenceId";
     roleNames[Roles::IncidenceTypeRole] = "incidenceType";
@@ -126,6 +127,8 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
         return todoPtr->recurs();
     } else if (role == Roles::IsOverdueRole) {
         return todoPtr->isOverdue();
+    } else if (role == Roles::IsReadOnly) {
+        return todoPtr->isReadOnly();
     } else if (role == Roles::IncidenceIdRole) {
         return todoPtr->uid();
     } else if (role == Roles::IncidenceTypeRole) {
@@ -405,7 +408,7 @@ void TodoSortFilterProxyModel::loadColors()
 {
     Q_EMIT layoutAboutToBeChanged();
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup rColorsConfig(config, "Resources Colors");
+    KConfigGroup rColorsConfig(config, QStringLiteral("Resources Colors"));
     const QStringList colorKeyList = rColorsConfig.keyList();
 
     for (const QString &key : colorKeyList) {
@@ -784,3 +787,5 @@ void TodoSortFilterProxyModel::setShowCompletedSubtodosInIncomplete(bool showCom
 }
 
 Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr)
+
+#include "moc_todosortfilterproxymodel.cpp"
