@@ -2,7 +2,9 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "mailplugin.h"
+#include "merkuro_mail_debug.h"
 
+#include <QLoggingCategory>
 #include <QQmlEngine>
 
 #include <MailCommon/EntityCollectionOrderProxyModel>
@@ -12,6 +14,7 @@
 #include "contactimageprovider.h"
 #include "helper.h"
 #include "mailapplication.h"
+#include "mailclient.h"
 #include "mailheadermodel.h"
 #include "mailmanager.h"
 #include "mailmodel.h"
@@ -48,6 +51,12 @@ void CalendarPlugin::registerTypes(const char *uri)
         return new MailCollectionHelper;
     });
 
+    qmlRegisterSingletonType<Akonadi::MailClient>("org.kde.merkuro.mail", 1, 0, "MailClient", [](QQmlEngine *engine, QJSEngine *scriptEngine) {
+        Q_UNUSED(engine)
+        Q_UNUSED(scriptEngine)
+        return new Akonadi::MailClient;
+    });
+
     qmlRegisterType<MailHeaderModel>("org.kde.merkuro.mail", 1, 0, "MailHeaderModel");
     qmlRegisterType<MessageLoader>(uri, 1, 0, "MessageLoader");
     qmlRegisterType<MessageParser>(uri, 1, 0, "MessageParser");
@@ -59,7 +68,7 @@ void CalendarPlugin::registerTypes(const char *uri)
 void CalendarPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
 {
     Q_UNUSED(uri);
-    engine->addImageProvider(QLatin1String("contact"), new ContactImageProvider);
+    engine->addImageProvider(QLatin1StringView("contact"), new ContactImageProvider);
 }
 
 #include "moc_mailplugin.cpp"
