@@ -26,7 +26,7 @@ class CollectionComboBoxModelPrivate;
  *
  * @code{.qml}
  *
- * import QtQuick.Controls 2.15 as QQC2
+ * import QtQuick.Controls as QQC2
  * import org.kde.akonadi 1.0 as Akonadi
  *
  * QQC2.ComboBox {
@@ -76,7 +76,7 @@ public:
     /**
      * Return the default collection id.
      */
-    qint64 defaultCollectionId() const;
+    [[nodiscard]] qint64 defaultCollectionId() const;
 
     /**
      * Sets the @p collection that shall be selected by default.
