@@ -19,12 +19,12 @@ class MimeTypes : public QObject
     Q_PROPERTY(QString mail READ mail CONSTANT)
 
 public:
-    MimeTypes(QObject *parent = nullptr);
-    QString calendar() const;
-    QString todo() const;
-    QString address() const;
-    QString contactGroup() const;
-    QString mail() const;
+    explicit MimeTypes(QObject *parent = nullptr);
+    [[nodiscard]] QString calendar() const;
+    [[nodiscard]] QString todo() const;
+    [[nodiscard]] QString address() const;
+    [[nodiscard]] QString contactGroup() const;
+    [[nodiscard]] QString mail() const;
 };
 }
 }
